@@ -1,32 +1,30 @@
 import os
 import yaml
 import colander
-from colander import SchemaNode
 from pprint import pprint
 from datetime import datetime
 
-from grano.core import db
-from grano.model import Schema, Attribute
-from grano.model.schema import ENTITY_DEFAULT_SCHEMA
+from grano.core import db, url_for
+from grano.lib.exc import NotImplemented
+from grano.model import Schema, Attribute, Project
 from grano.logic.validation import Invalid, database_name
 from grano.logic.references import ProjectRef
+from grano.logic import projects as projects_logic
 from grano.logic import attributes
 
-TYPES_VALIDATOR = colander.OneOf(Attribute.DATATYPES.keys())
 
 
 class AttributeValidator(colander.MappingSchema):
-    name = SchemaNode(colander.String(),
-                      validator=database_name)
-    label = SchemaNode(colander.String(),
-                       validator=colander.Length(min=3))
-    description = SchemaNode(colander.String(),
-                             missing='', default='')
-    datatype = SchemaNode(colander.String(),
-                          validator=TYPES_VALIDATOR,
-                          missing='string')
-    hidden = SchemaNode(colander.Boolean(),
-                        missing=False)
+    name = colander.SchemaNode(colander.String(),
+        validator=database_name)
+    label = colander.SchemaNode(colander.String(),
+        validator=colander.Length(min=3))
+    description = colander.SchemaNode(colander.String(),
+        missing='', default='')
+    datatype = colander.SchemaNode(colander.String(),
+        validator=colander.OneOf(Attribute.DATATYPES.keys()), missing='string')
+    hidden = colander.SchemaNode(colander.Boolean(),
+        missing=False)
 
 
 class Attributes(colander.SequenceSchema):
@@ -34,17 +32,19 @@ class Attributes(colander.SequenceSchema):
 
 
 class SchemaValidator(colander.MappingSchema):
-    project = SchemaNode(ProjectRef())
-    name = SchemaNode(colander.String(),
-                      validator=database_name)
-    label = SchemaNode(colander.String(),
-                       validator=colander.Length(min=3))
-    hidden = SchemaNode(colander.Boolean(),
-                        missing=False)
-    obj = SchemaNode(colander.String(),
-                     validator=colander.OneOf(['entity', 'relation']))
-    meta = SchemaNode(colander.Mapping(unknown='preserve'),
-                      missing={})
+    project = colander.SchemaNode(ProjectRef())
+    name = colander.SchemaNode(colander.String(),
+        validator=database_name)
+    label = colander.SchemaNode(colander.String(),
+        validator=colander.Length(min=3))
+    label_in = colander.SchemaNode(colander.String(),
+        missing=None, validator=colander.Length(min=3))
+    label_out = colander.SchemaNode(colander.String(),
+        missing=None, validator=colander.Length(min=3))
+    hidden = colander.SchemaNode(colander.Boolean(),
+        missing=False)
+    obj = colander.SchemaNode(colander.String(),
+        validator=colander.OneOf(['entity', 'relation']))
     attributes = Attributes()
 
 
@@ -60,12 +60,14 @@ def save(data, schema=None):
         schema.project = data.get('project')
 
     schema.label = data.get('label')
+    schema.label_in = data.get('label_in') or schema.label
+    schema.label_out = data.get('label_out') or schema.label
+
     schema.obj = data.get('obj')
     schema.hidden = data.get('hidden')
-    schema.meta = data.get('meta')
     schema.project.updated_at = datetime.utcnow()
     db.session.add(schema)
-
+    
     names = []
     for attribute in data.get('attributes', []):
         attribute['schema'] = schema
@@ -104,6 +106,8 @@ def export_schema(project, path):
     if not os.path.exists(path):
         os.makedirs(path)
     for schema in Schema.all().filter_by(project=project):
+        if schema.name == 'base':
+            continue
         fn = os.path.join(path, schema.name + '.yaml')
         with open(fn, 'w') as fh:
             dumped = yaml.safe_dump(schema.to_dict(schema),
