@@ -2,7 +2,7 @@ from grano.core import db
 
 from grano.model.schema import Schema
 from grano.model.attribute import Attribute
-from grano.model.property import Property
+from grano.model.property import Property, EntityProperty, RelationProperty
 from grano.model.entity import Entity
 from grano.model.relation import Relation
 from grano.model.account import Account
