@@ -3,10 +3,10 @@ from sqlalchemy.orm import aliased
 from sqlalchemy.sql import func
 
 from grano.lib.exc import BadRequest
-from grano.lib.args import arg_bool
 from grano.lib.pager import Pager
 from grano.model import Project, Relation
-from grano.model import Entity, Property, Schema, db
+from grano.model import Entity, EntityProperty, Schema, db
+from grano.model import RelationProperty
 from grano.views import filters
 
 
@@ -33,7 +33,7 @@ def apply_property_facet(q, facet, cls, parent_obj):
     return q.group_by(*columns)
 
 
-def parse_entity_facets(entity_obj, full_facet, facet, q):
+def parse_entity_facets(entity_obj, facet, q):
     """ Parse a facet related to a relation object and return a
     modified query. """
     # TODO: Status facet.
@@ -44,28 +44,26 @@ def parse_entity_facets(entity_obj, full_facet, facet, q):
         return apply_facet_obj(q, facet_obj)
     elif facet == 'schema':
         facet_obj = aliased(Schema)
-        if not arg_bool('facet_%s_hidden' % full_facet, default=False):
-            q = q.filter(facet_obj.hidden == False)
         q = q.join(facet_obj, entity_obj.schemata)
         return apply_facet_obj(q, facet_obj)
     elif facet.startswith('properties.'):
-        return apply_property_facet(q, facet, Property,
+        return apply_property_facet(q, facet, EntityProperty,
                                     entity_obj)
     elif facet.startswith('inbound.'):
         _, subfacet = facet.split('.', 1)
         rel_obj = aliased(Relation)
         q = q.join(rel_obj, entity_obj.inbound)
-        return parse_relation_facets(rel_obj, full_facet, subfacet, q)
+        return parse_relation_facets(rel_obj, subfacet, q)
     elif facet.startswith('outbound.'):
         _, subfacet = facet.split('.', 1)
         rel_obj = aliased(Relation)
         q = q.join(rel_obj, entity_obj.outbound)
-        return parse_relation_facets(rel_obj, full_facet, subfacet, q)
+        return parse_relation_facets(rel_obj, subfacet, q)
     else:
         raise BadRequest("Unknown facet: %s" % facet)
 
 
-def parse_relation_facets(relation_obj, full_facet, facet, q):
+def parse_relation_facets(relation_obj, facet, q):
     """ Parse a facet related to an entity and return a modified
     query. """
     if facet == 'project':
@@ -74,23 +72,21 @@ def parse_relation_facets(relation_obj, full_facet, facet, q):
         return apply_facet_obj(q, facet_obj)
     elif facet == 'schema':
         facet_obj = aliased(Schema)
-        if not arg_bool('facet_%s_hidden' % full_facet, default=False):
-            q = q.filter(facet_obj.hidden == False)
         q = q.join(facet_obj, relation_obj.schema)
         return apply_facet_obj(q, facet_obj)
     elif facet.startswith('properties.'):
-        return apply_property_facet(q, facet, Property,
+        return apply_property_facet(q, facet, RelationProperty,
                                     relation_obj)
     elif facet.startswith('source.'):
         _, subfacet = facet.split('.', 1)
         ent_obj = aliased(Entity)
         q = q.join(ent_obj, relation_obj.source)
-        return parse_entity_facets(ent_obj, full_facet, subfacet, q)
+        return parse_entity_facets(ent_obj, subfacet, q)
     elif facet.startswith('target.'):
         _, subfacet = facet.split('.', 1)
         ent_obj = aliased(Entity)
         q = q.join(ent_obj, relation_obj.target)
-        return parse_entity_facets(ent_obj, full_facet, subfacet, q)
+        return parse_entity_facets(ent_obj, subfacet, q)
     else:
         raise BadRequest("Unknown facet: %s" % facet)
 
@@ -127,7 +123,7 @@ def make_facets(parent_alias, filter_func, parser_func):
         q = q.add_columns(facet_count)
         q = q.order_by(facet_count.desc())
         q = filter_func(q, parent_obj)
-        q = parser_func(parent_obj, facet, facet, q)
+        q = parser_func(parent_obj, facet, q)
         facets[facet] = Pager(q, name='facet_%s' % facet,
                               results_converter=results_process)
     return facets
